@@ -44,7 +44,7 @@ def detail(request, slug=None, template_name="news/view.html"):
         if not request.user.is_authenticated():
             raise Http404
 
-        if not has_perm(request.user, 'news.view_news', news):
+        if not request.user.profile.is_superuser:
             raise Http403
 
     EventLog.objects.log(instance=news)
